<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>CSVColumnConfigurationDialog</name>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="14"/>
        <source>Select the role of the column</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="23"/>
        <source>Column role</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="29"/>
        <source>Annotation start position</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="39"/>
        <source>Add offset</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="52"/>
        <source> bp</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="65"/>
        <source>Annotation end position</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="75"/>
        <source>Inclusive</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="85"/>
        <source>Annotation length</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="92"/>
        <source>Complement strand mark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="102"/>
        <source>Mark value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="119"/>
        <source>Annotation name</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="126"/>
        <source>Qualifier</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="147"/>
        <source>Ignore this column</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="205"/>
        <source>Ok</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="212"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ExportChromatogramDialog</name>
    <message>
        <location filename="../src/ui/ExportChromatogramDialog.ui" line="14"/>
        <source>Export chromatogram file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportChromatogramDialog.ui" line="25"/>
        <source>Export to file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportChromatogramDialog.ui" line="35"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportChromatogramDialog.ui" line="42"/>
        <source>File format to use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportChromatogramDialog.ui" line="56"/>
        <source>Reversed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportChromatogramDialog.ui" line="66"/>
        <source>Complemented</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportChromatogramDialog.ui" line="75"/>
        <source>Add document to the project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportChromatogramDialog.ui" line="113"/>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportChromatogramDialog.ui" line="123"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportAnnotationsFromCSVDialog</name>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="14"/>
        <source>Import annotations from CSV</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="25"/>
        <source>File to read</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="35"/>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="60"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="44"/>
        <source>Results</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="50"/>
        <source>Result file</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="67"/>
        <source>File format</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="77"/>
        <source>Add result file to project</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="96"/>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="111"/>
        <source>Column separator</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="103"/>
        <source>File parsing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="140"/>
        <source>,</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="150"/>
        <source>Guess</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="157"/>
        <source>Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="177"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="184"/>
        <source>First  lines to skip</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="207"/>
        <source>Do not skip</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="210"/>
        <source> line(s)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="220"/>
        <source>Skip all lines starts with the text</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="246"/>
        <source>#</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="266"/>
        <source>Remove quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="283"/>
        <source>Default annotation name</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="296"/>
        <source>misc_feature</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="259"/>
        <source>Interpret multiple separators like a single separator (try when separator is a whitespace character)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="313"/>
        <source>Results preview</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="333"/>
        <source>Preview</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="360"/>
        <source>Raw file preview:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="410"/>
        <source>Run</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="417"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::ADVExportContext</name>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="78"/>
        <source>Export selected sequence region...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="81"/>
        <source>Export sequence of selected annotations...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="87"/>
        <source>Align selected annotations...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="90"/>
        <source>Align selected annotations (amino acids)...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="93"/>
        <source>Align selected sequence regions...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="96"/>
        <source>Align selected sequence regions (amino acids)...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="99"/>
        <source>Export sequences by &apos;id&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="101"/>
        <source>Export sequences by &apos;accession&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="103"/>
        <source>Export sequences by &apos;db_xref&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="205"/>
        <source>Fetch sequences from remote database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="208"/>
        <source>Fetch sequences by &apos;id&apos; %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="212"/>
        <source>Fetch sequences by &apos;accession&apos; %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="216"/>
        <source>Fetch sequences by &apos;db_xref&apos; %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="567"/>
        <source>Create alignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="568"/>
        <source>Save alignment to file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="239"/>
        <location filename="../src/ExportSequenceViewItems.cpp" line="387"/>
        <source>No annotations selected!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="84"/>
        <source>Export annotations...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="325"/>
        <source>No sequence regions selected!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="437"/>
        <source>At least 2 annotations are required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="455"/>
        <source>Different sequence alphabets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="514"/>
        <source>At least 2 sequences required</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="446"/>
        <source>No sequence object found</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="472"/>
        <location filename="../src/ExportSequenceViewItems.cpp" line="531"/>
        <source>Alignment is too large</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="508"/>
        <source>Can&apos;t derive alignment alphabet</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::CSVColumnConfigurationDialog</name>
    <message>
        <location filename="../src/CSVColumnConfigurationDialog.cpp" line="66"/>
        <source>Invalid qualifier name!</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::DNAExportPlugin</name>
    <message>
        <source>dna_export_name</source>
        <translation type="obsolete">DNA Export</translation>
    </message>
    <message>
        <source>dna_export_desc</source>
        <translation type="obsolete">Routines to export or align multiple DNA sequences </translation>
    </message>
    <message>
        <location filename="../src/DNAExportPlugin.cpp" line="23"/>
        <source>DNA export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPlugin.cpp" line="23"/>
        <source>Export and import support for DNA &amp; protein sequences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::DNAExportService</name>
    <message>
        <source>dna_export_service_name</source>
        <translation type="obsolete">DNA Export</translation>
    </message>
    <message>
        <source>dna_export_service_desc</source>
        <translation type="obsolete">This service provides routines to export DNA sequence to FASTA format</translation>
    </message>
    <message>
        <location filename="../src/DNAExportPlugin.cpp" line="48"/>
        <source>DNA export service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPlugin.cpp" line="48"/>
        <source>Export and import support for DNA &amp; protein sequences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ExportAlignmentTask</name>
    <message>
        <location filename="../src/ExportTasks.cpp" line="58"/>
        <source>Export alignment to &apos;%1&apos;</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::ExportAnnotationSequenceSubTask</name>
    <message>
        <location filename="../src/ExportSequenceTask.cpp" line="240"/>
        <source>Extract annotation regions</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ExportAnnotationSequenceTask</name>
    <message>
        <location filename="../src/ExportSequenceTask.cpp" line="224"/>
        <source>Export annotations</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ExportAnnotations2CSVTask</name>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="20"/>
        <source>Export2CSV</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="56"/>
        <source>No IO adapter found for URL: %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="68"/>
        <source>Group</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="69"/>
        <source>Name</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="70"/>
        <source>Start</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="71"/>
        <source>End</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="72"/>
        <source>Length</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="73"/>
        <source>Complement</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="75"/>
        <source>Sequence</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="102"/>
        <source>yes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="104"/>
        <source>no</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::ExportAnnotationsDialog</name>
    <message>
        <location filename="../src/ui/ExportAnnotationsDialog.ui" line="14"/>
        <source>Export annotations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportAnnotationsDialog.ui" line="25"/>
        <source>Export to file:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportAnnotationsDialog.ui" line="37"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportAnnotationsDialog.ui" line="49"/>
        <source>File format:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportAnnotationsDialog.ui" line="58"/>
        <source>Save sequences under annotations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotationsDialog.cpp" line="100"/>
        <source>Select file to save annotations</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::ExportChromatogramDialog</name>
    <message>
        <location filename="../src/ExportChromatogramDialog.cpp" line="36"/>
        <source>Select a file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportChromatogramDialog.cpp" line="47"/>
        <source>File name is empty!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ExportDNAChromatogramTask</name>
    <message>
        <location filename="../src/ExportTasks.cpp" line="162"/>
        <source>Export chromatogram to SCF</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ExportMSA2MSADialog</name>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="20"/>
        <source>Dialog</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="28"/>
        <source>Export to file</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="38"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="45"/>
        <source>File format to use</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="55"/>
        <source>Amino translation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="67"/>
        <source>Add document to the project</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="77"/>
        <source>Export range</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="83"/>
        <source>Whole alignment</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="93"/>
        <source>Selected rows</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="134"/>
        <source>Export</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="141"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportMSA2MSADialog.cpp" line="33"/>
        <source>Export alignment</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportMSA2MSADialog.cpp" line="65"/>
        <source>File is empty</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::ExportMSA2MSATask</name>
    <message>
        <location filename="../src/ExportTasks.cpp" line="109"/>
        <source>Export alignment to alignment: %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportTasks.cpp" line="135"/>
        <source>Out of memory</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::ExportMSA2SequencesDialog</name>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="14"/>
        <source>Convert alignment to separate sequences</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="25"/>
        <source>Export to file</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="35"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="42"/>
        <source>File format to use</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="54"/>
        <source>Add document to the project</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="64"/>
        <source>Gap characters (&apos;-&apos;)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="70"/>
        <source>Keep</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="80"/>
        <source>Trim</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="118"/>
        <source>Export</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="128"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportMSA2SequencesDialog.cpp" line="37"/>
        <source>File name is empty!</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::ExportMSA2SequencesTask</name>
    <message>
        <location filename="../src/ExportTasks.cpp" line="78"/>
        <source>Export alignment to sequence: %1</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::ExportProjectViewItemsContoller</name>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="49"/>
        <source>Export sequences</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="52"/>
        <source>Export sequences as alignment</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="55"/>
        <source>Export alignment to sequence format</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="58"/>
        <source>Export nucleic alignment to amino translation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="61"/>
        <source>Import annotations from CSV file</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="64"/>
        <source>Export chromatogram to SCF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="67"/>
        <source>Export annotations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="92"/>
        <location filename="../src/ExportProjectViewItems.cpp" line="98"/>
        <location filename="../src/ExportProjectViewItems.cpp" line="111"/>
        <location filename="../src/ExportProjectViewItems.cpp" line="119"/>
        <source>Export</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="132"/>
        <source>Import</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="177"/>
        <location filename="../src/ExportProjectViewItems.cpp" line="238"/>
        <source>No sequence objects selected!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="270"/>
        <location filename="../src/ExportProjectViewItems.cpp" line="293"/>
        <source>Select one alignment object to export</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="342"/>
        <source>Select one chromatogram object to export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="378"/>
        <source>Select one annotation object to export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="387"/>
        <source>Selected object doesn&apos;t have annotations</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ExportSequenceTask</name>
    <message>
        <location filename="../src/ExportSequenceTask.cpp" line="25"/>
        <source>Export sequence to &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceTask.cpp" line="41"/>
        <source>Complement translation not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceTask.cpp" line="70"/>
        <source>Amino  translation not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceTask.cpp" line="104"/>
        <source>Back-translation not found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ExportSequences2MSADialog</name>
    <message>
        <location filename="../src/ui/ExportSequences2MSADialog.ui" line="14"/>
        <source>Export sequences as alignment</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequences2MSADialog.ui" line="25"/>
        <source>Export to file</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequences2MSADialog.ui" line="35"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequences2MSADialog.ui" line="42"/>
        <source>File format to use</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequences2MSADialog.ui" line="54"/>
        <source>Add document to the project</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequences2MSADialog.ui" line="92"/>
        <source>Export</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequences2MSADialog.ui" line="102"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportSequences2MSADialog.cpp" line="37"/>
        <source>File name is empty!</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::ExportSequencesDialog</name>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="20"/>
        <source>Export selected sequences</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="31"/>
        <source>Export to file</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="41"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="48"/>
        <source>File format to use</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="60"/>
        <source>Export with annotations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="67"/>
        <source>Add document to the project</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="77"/>
        <source>Convertion options</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="83"/>
        <source>Save direct strand</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="93"/>
        <source>Save complement strand</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="100"/>
        <source>Save both strands</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="107"/>
        <source>Translate to amino alphabet</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="117"/>
        <source>Save all amino frames</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="147"/>
        <source>Back translation options</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="153"/>
        <source>Translate back to nucleic alphabet</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="165"/>
        <source>Most frequently used codons</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="192"/>
        <source>Organism:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="251"/>
        <source>Save as separate sequences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="178"/>
        <source>Frequency distribution</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="137"/>
        <source>Use custom translation table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="214"/>
        <source>Merge options</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="222"/>
        <source>Add gap symbols between sequences</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="244"/>
        <source>Merge sequences</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="292"/>
        <source>Export</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="299"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportSequencesDialog.cpp" line="37"/>
        <source>Export sequences</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportSequencesDialog.cpp" line="130"/>
        <source>Select organism</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportSequencesDialog.cpp" line="198"/>
        <source>File is empty</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportSequencesDialog.cpp" line="203"/>
        <source>Organism for back translation not specified</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::GTest</name>
    <message>
        <location filename="../src/DNAExportPluginTests.cpp" line="93"/>
        <source>Unable to create temporary file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPluginTests.cpp" line="112"/>
        <source>Invalid translation table num: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPluginTests.cpp" line="128"/>
        <location filename="../src/DNAExportPluginTests.cpp" line="134"/>
        <source>Invalid base : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPluginTests.cpp" line="147"/>
        <location filename="../src/DNAExportPluginTests.cpp" line="184"/>
        <location filename="../src/DNAExportPluginTests.cpp" line="207"/>
        <source>context not found %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPluginTests.cpp" line="153"/>
        <location filename="../src/DNAExportPluginTests.cpp" line="190"/>
        <location filename="../src/DNAExportPluginTests.cpp" line="213"/>
        <source>container of object with type &quot;%1&quot; is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPluginTests.cpp" line="220"/>
        <source>Unexpected alignment length %1, expected %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPluginTests.cpp" line="225"/>
        <source>Unexpected alignment size %1, expected %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPluginTests.cpp" line="234"/>
        <source>Invalid name for row %1: %2, expected %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPluginTests.cpp" line="239"/>
        <source>Invalid char at row %1 column %2: %3, expected %4</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::GetSequenceByIdDialog</name>
    <message>
        <location filename="../src/GetSequenceByIdDialog.cpp" line="24"/>
        <source>Select directory to save</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ImportAnnotationsFromCSVDialog</name>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="57"/>
        <source>Save imported annotations to</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="86"/>
        <source>//The script parses input line
 // and returns an array of parsed elements as the result
var %1; //input line
var %2; //parsed line number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="130"/>
        <source>Invalid start position/end position/length configuration!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="134"/>
        <source>Multiple columns are used as a name!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="282"/>
        <source>Column separator value: [%1], hex: [%2], length: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="348"/>
        <source>Script is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="363"/>
        <source>Output file format is not set!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="358"/>
        <source>Output file name is not set!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="138"/>
        <source>Invalid default annotation name!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="259"/>
        <source>Failed to guess separator sequence!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="280"/>
        <source>Column separator</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="301"/>
        <source>Select CSV file to read</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="315"/>
        <source>Enter input CSV file name</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="342"/>
        <source>Separator value is not set</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="445"/>
        <source>[ignored]</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="448"/>
        <source>[qualifier %1]</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="451"/>
        <source>[name]</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="455"/>
        <source>[start position with offset %1]</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="457"/>
        <source>[start position]</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="462"/>
        <source>[end position (inclusive)]</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="464"/>
        <source>[end position]</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="468"/>
        <source>[length]</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="472"/>
        <source>[complement]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="474"/>
        <source>[complement if &apos;%1&apos;]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ImportAnnotationsFromCSVTask</name>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="29"/>
        <source>Import annotations from CSV</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="105"/>
        <source>Annotations can&apos;t be added to the document %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="109"/>
        <source>Document is locked and can&apos;t be modified %1</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::ImportPhredQualityPrompter</name>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="82"/>
        <source> from &lt;u&gt;%1&lt;/u&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="84"/>
        <source>unset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="86"/>
        <source>Import PHRED quality scores in file %1  to the sequences %2 and send the sequences to the output.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::ImportPhredQualityWorker</name>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="32"/>
        <source>DNA sequences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="33"/>
        <source>The PHRED scores will be imported to these sequences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="34"/>
        <source>DNA sequences with imported qualities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="35"/>
        <source>These sequences have quality scores.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="44"/>
        <source>PHRED input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="45"/>
        <source>Path to file with PHRED quality scores.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="46"/>
        <source>Quality format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="47"/>
        <source>Choose format to encode quality scores.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="52"/>
        <source>Import PHRED qualities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="53"/>
        <source>Add corresponding PHRED quality scores to the sequences.
You can use this worker to convert .fasta and .qual pair to fastq format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="116"/>
        <source>Sequence list is empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="142"/>
        <source>Import of qualities is finished.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::WriteAnnotationsPrompter</name>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="173"/>
        <source>unset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="181"/>
        <source>Save all annotations from &lt;u&gt;%1&lt;/u&gt; to %2 in &lt;u&gt;%3&lt;/u&gt; format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::WriteAnnotationsWorker</name>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="54"/>
        <source>Unrecognized formatId: &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="60"/>
        <source>Unspecified URL to write %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="70"/>
        <source>Annotations name not specified. Default value used: &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="116"/>
        <source>Input annotations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="117"/>
        <source>Input annotations which will be written to output file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="134"/>
        <source>Annotations name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="135"/>
        <source>Object name of saving annotations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="140"/>
        <source>Write annotations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="141"/>
        <source>Writes all supplied annotations to file(s) in selected formatId.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::MSAExportContext</name>
    <message>
        <location filename="../src/ExportAlignmentViewItems.cpp" line="59"/>
        <source>Export amino translation of alignment rows...</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::ReadCSVAsAnnotationsTask</name>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="155"/>
        <source>Parse CSV file %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="210"/>
        <source>Invalid annotation name: &apos;%1&apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="218"/>
        <source>Start offset is not numeric: &apos;%1&apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="225"/>
        <source>End offset is not numeric: &apos;%1&apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="232"/>
        <source>Length is not numeric: &apos;%1&apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="267"/>
        <source>Invalid location: start: %1  len: %2, in line :%3, ignoring</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="275"/>
        <source>Can&apos;t parse line: &apos;%1&apos;, error = %2, ignoring</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="354"/>
        <source>Script result is not an array of strings!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>getSequenceByIdDialog</name>
    <message>
        <location filename="../src/ui/GetSequenceByIdDialog.ui" line="14"/>
        <source>Get sequences by ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/GetSequenceByIdDialog.ui" line="22"/>
        <source>The sequences from selected BLAST results will be downloaded from
 NCBI Genbank by their GI identifier
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/GetSequenceByIdDialog.ui" line="33"/>
        <source>Save to directctory:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/GetSequenceByIdDialog.ui" line="43"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/GetSequenceByIdDialog.ui" line="52"/>
        <source>Add to project</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
